@@ -73,7 +73,7 @@ json_syck_parser_handler
 yaml_syck_parser_handler
 #endif
 (SyckParser *p, SyckNode *n) {
-    SV *sv;
+    SV *sv = NULL;
     AV *seq;
     HV *map;
     long i;
@@ -203,22 +203,28 @@ yaml_syck_parser_handler
                 sv = newSVpv(blob, len);
 #ifndef YAML_IS_JSON
 #ifdef PERL_LOADMOD_NOIMPORT
-            } else if (load_code && (strEQ(id, "perl/code") || strnEQ(id, "perl/code:", 10))) {
+            } else if (strEQ(id, "perl/code") || strnEQ(id, "perl/code:", 10)) {
                 SV *cv;
-                SV *text, *sub;
+                SV *sub;
                 char *pkg = id + 10;
 
-                /* This code is copypasted from Storable.xs */
+                if (load_code) {
+                    SV *text;
 
-                /*
-                 * prepend "sub " to the source
-                 */
+                    /* This code is copypasted from Storable.xs */
 
-                text = newSVpvn(n->data.str->ptr, n->data.str->len);
+                    /*
+                     * prepend "sub " to the source
+                     */
 
-                sub = newSVpvn("sub ", 4);
-                sv_catpv(sub, SvPV_nolen(text)); /* XXX no sv_catsv! */
-                SvREFCNT_dec(text);
+                    text = newSVpvn(n->data.str->ptr, n->data.str->len);
+
+                    sub = newSVpvn("sub ", 4);
+                    sv_catpv(sub, SvPV_nolen(text)); /* XXX no sv_catsv! */
+                    SvREFCNT_dec(text);
+                } else {
+                    sub = newSVpvn("sub {}", 6);
+                }
 
                 ENTER;
                 SAVETMPS;
@@ -229,12 +235,9 @@ yaml_syck_parser_handler
 
                 if (cv && SvROK(cv) && SvTYPE(SvRV(cv)) == SVt_PVCV) {
                     sv = cv;
-                } else {
-                    croak("code %s did not evaluate to a subroutine reference\n", SvPV_nolen(sub));
                 }
-
-                if ( (*(pkg - 1) != '\0') && (*pkg != '\0') ) {
-                    sv_bless(sv, gv_stashpv(pkg, TRUE));
+                else {
+                    croak("code %s did not evaluate to a subroutine reference\n", SvPV_nolen(sub));
                 }
 
                 SvREFCNT_inc(sv); /* XXX seems to be necessary */
@@ -242,6 +245,10 @@ yaml_syck_parser_handler
                 FREETMPS;
                 LEAVE;
 
+                if ( (*(pkg - 1) != '\0') && (*pkg != '\0') ) {
+                    sv_bless(sv, gv_stashpv(pkg, TRUE));
+                }
+
                 /* END Storable */
 
             } else if (strnEQ( n->data.str->ptr, REF_LITERAL, 1+REF_LITERAL_LENGTH)) {
@@ -578,7 +585,6 @@ static SV * LoadYAML (char *s) {
     SV *obj              = &PL_sv_undef;
     SV *use_code         = GvSV(gv_fetchpv(form("%s::UseCode", PACKAGE_NAME), TRUE, SVt_PV));
     SV *load_code        = GvSV(gv_fetchpv(form("%s::LoadCode", PACKAGE_NAME), TRUE, SVt_PV));
-    SV *implicit_binary  = GvSV(gv_fetchpv(form("%s::ImplicitBinary", PACKAGE_NAME), TRUE, SVt_PV));
     SV *implicit_typing  = GvSV(gv_fetchpv(form("%s::ImplicitTyping", PACKAGE_NAME), TRUE, SVt_PV));
     SV *implicit_unicode = GvSV(gv_fetchpv(form("%s::ImplicitUnicode", PACKAGE_NAME), TRUE, SVt_PV));
     SV *singlequote      = GvSV(gv_fetchpv(form("%s::SingleQuote", PACKAGE_NAME), TRUE, SVt_PV));
@@ -756,7 +762,7 @@ yaml_syck_emitter_handler
                 }
                 else {
                     MAGIC *mg;
-                    if (mg = mg_find(SvRV(sv), PERL_MAGIC_qr)) {
+                    if ( (mg = mg_find(SvRV(sv), PERL_MAGIC_qr) ) ) {
                         if (strEQ(ref, "Regexp")) {
                             strcat(tag, "regexp");
                             ref += 6; /* empty string */
